==> hugo_0.110.0.orig.tar.gz: hugo-0.110.0/docs/content/en/getting-started/external-learning-resources/index.md <==
---
title: External Learning Resources
linktitle: External Learning Resources
description: A list of tutorials and books on Hugo.
date: 2019-10-20
publishdate: 2019-10-20
lastmod: 2019-10-20
keywords: [books, tutorials, learning, usage]
menu:
  docs:
    parent: "getting-started"
    weight: 70
weight: 70
sections_weight: 70
draft: false
toc: false
---

## Books

### Hugo In Action

[![Hugo In Action](hia.jpg)](https://www.manning.com/books/hugo-in-action)

Hugo in Action is a step-by-step guide to using Hugo to create static websites. Working with a complete example website and source code samples, you’ll learn how to build and host a low-maintenance, high-performance site that will wow your users and stay stable without relying on a third-party server.

[Hugo In Action Home Page](https://www.manning.com/books/hugo-in-action)

### Build Websites with Hugo

[Build Websites with Hugo - Fast Web Development with Markdown (2020)](https://pragprog.com/titles/bhhugo/) by Brian P. Hogan.

## Beginner tutorials

### Hugo tutorial by CloudCannon

[Step-by-step written tutorial](https://cloudcannon.com/community/learn/hugo-101/) to teach you the basics of creating a Hugo site.

## Video tutorials

* Mike Dane explains the various features of Hugo via dedicated tutorials on [YouTube](https://www.youtube.com/watch?list=PLLAZ4kZ9dFpOnyRlyS-liKL5ReHDcj4G3&v=qtIqKaDlqXo).

* [Introduction to building your first Hugo site](https://cloudcannon.com/community/learn/hugo-beginner-tutorial/) by Mike Neumegen.

==> hugo_0.111.3.orig.tar.gz: hugo-0.111.3/docs/content/en/getting-started/external-learning-resources/index.md <==
---
title: External Learning Resources
linktitle: External Learning Resources
description: A list of tutorials and books on Hugo.
date: 2019-10-20
publishdate: 2019-10-20
lastmod: 2019-10-20
keywords: [books, tutorials, learning, usage]
menu:
  docs:
    parent: "getting-started"
    weight: 70
weight: 70
sections_weight: 70
draft: false
toc: false
---

## Books

### Hugo In Action

[![Hugo In Action](hia.jpg)](https://www.manning.com/books/hugo-in-action)

Hugo in Action is a step-by-step guide to using Hugo to create static websites. Working with a complete example website and source code samples, you’ll learn how to build and host a low-maintenance, high-performance site that will wow your users and stay stable without relying on a third-party server.

[Hugo In Action Home Page](https://www.manning.com/books/hugo-in-action)

### Build Websites with Hugo

[Build Websites with Hugo - Fast Web Development with Markdown (2020)](https://pragprog.com/titles/bhhugo/) by Brian P. Hogan.

## Beginner tutorials

### Hugo tutorial by CloudCannon

[Step-by-step written tutorial](https://cloudcannon.com/community/learn/hugo-beginner-tutorial/) to teach you the basics of creating a Hugo site.

## Video tutorials

* Mike Dane explains the various features of Hugo via dedicated tutorials on [YouTube](https://www.youtube.com/watch?list=PLLAZ4kZ9dFpOnyRlyS-liKL5ReHDcj4G3&v=qtIqKaDlqXo).

* [Introduction to building your first Hugo site](https://cloudcannon.com/community/learn/hugo-beginner-tutorial/) by Mike Neumegen.
